@@ -28,7 +28,7 @@ def load_trigram_file(f):
         for line in file_handle:
             l = line.strip().split("\t")
             words = l[0].split(" ")
-            trgs.append([Trigram(Word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1]))])
+            trgs.append([Trigram(word=words[-1],word_i_minus_one=words[1],word_i_minus_two=words[0],count=int(l[1]))])
     if trgs != []:
         g2 = add_trigram_records.chunks(trgs,100000).apply_async()
 
